
unit h2wiringpi;

(* Pascal wrapper unit for Gordon Henderson wiringPi library. The source can
 * be found at https://http://wiringpi.com
 *
 * hwiringpi: origanal Wrapper and
 * pascal sample by Alex Schaller.
 *
 * Fork
 * h2wiringpi: Version 0.1 By Allen Roton
 * wiringPi Version 2.23
 * $linklib
 *
 * wiringPi:
 *	Arduino compatable (ish) Wiring library for the Raspberry Pi
 *	Copyright (c) 2012 Gordon Henderson
 ***********************************************************************
 * This file is part of wiringPi:
 *	https://projects.drogon.net/raspberry-pi/wiringpi/
 *
 *    wiringPi is free software: you can redistribute it and/or modify
 *    it under the terms of the GNU General Public License as published by
 *    the Free Software Foundation, either version 3 of the License, or
 *    (at your option) any later version.
 *
 *    wiringPi is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    GNU General Public License for more details.
 *
 *    You should have received a copy of the GNU General Public License
 *    along with wiringPi.  If not, see <http://www.gnu.org/licenses/>.
 ***********************************************************************
 *)




{$linklib c}
{$linklib libwiringPi}
interface
// Handy defines
const
     NUM_PINS          =        17;
     WPI_MODE_PINS	=	 0;

     WPI_MODE_GPIO	=	 1;
     WPI_MODE_GPIO_SYS	=        2;
     WPI_MODE_PHYS	=	 3;
     WPI_MODE_PIFACE	=	 4;
     WPI_MODE_UNINITIALISED=	-1;

// Pin modes

 	INPUT	=		 0;
	OUTPUT	=		 1;
	PWM_OUTPUT=		 2;
	GPIO_CLOCK=		 3;
	SOFT_PWM_OUTPUT=	 4;
	SOFT_TONE_OUTPUT=	 5;
	PWM_TONE_OUTPUT=	 6;

	LOW=			 0;
	HIGH=			 1;

// Pull up/down/none

	PUD_OFF=		 0;
	PUD_DOWN=		 1;
	PUD_UP=			 2;

// PWM

	PWM_MODE_MS=		0;
	PWM_MODE_BAL=		1;

// Interrupt levels

	INT_EDGE_SETUP=		0;
	INT_EDGE_FALLING=	1;
	INT_EDGE_RISING=	2;
	INT_EDGE_BOTH=		3;
{
// Pi model types and version numbers
//	Intended for the GPIO program Use at your own risk.

	PI_MODEL_UNKNOWN=	0
	PI_MODEL_A=		1
	PI_MODEL_B		2
	PI_MODEL_BP		3
	PI_MODEL_CM		4
	PI_MODEL_AP		5
	PI_MODEL_2		6

	PI_VERSION_UNKNOWN	0
	PI_VERSION_1		1
	PI_VERSION_1_1		2
	PI_VERSION_1_2		3
	PI_VERSION_2		4

	PI_MAKER_UNKNOWN	0
	PI_MAKER_EGOMAN		1
	PI_MAKER_SONY		2
	PI_MAKER_QISDA		3
	PI_MAKER_MBEST		4


 }

    // Pin mappings from P1 connector to WiringPi library
    // Px represents to physical pin on the RaspberryPi P1 connector

    // P1
    // P2
    P3  = 8;
    // P4
    P5  = 9;
    //P6
    P7  = 7;
    P8  = 15;
    //P9
    P10 = 16;
    P11 = 0;
    P12 = 1;
    P13 = 2;
    //P14
    P15 = 3;
    P16 = 4;
    // P17
    P18 = 5;
    P19 = 12;
    // P20
    P21 = 13;
    P22 = 6;
    P23 = 14;
    P24 = 10;
    // P25
    P26 = 11;
    // pi2
    P27 = 30;
    P28 = 31;
    P29 = 21;
    // P30 =  GND
    P31  = 22;
    P32 = 26;
    P33 = 23;
    //P34 = GND;
    P35 = 24;
    P36 = 27;
    P37 = 24;
    P38 = 28;
    // P39 = GND
    P40 = 29;

    // Core wiringPi functions

//extern struct wiringPiNodeStruct *wiringPiFindNode (int pin) ;

//extern struct wiringPiNodeStruct *wiringPiNewNode  (int pinBase, int numPins) ;

//extern int  wiringPiSetup       (void) ;
Function wiringPiSetup:longint;cdecl;external;
//extern int  wiringPiSetupSys    (void) ;
 Function wiringPiSetupSys:longint;cdecl;external;
//extern int  wiringPiSetupGpio   (void) ;
Function wiringPiSetupGpio:longint;cdecl;external;
//extern int  wiringPiSetupPhys   (void) ;
Function wiringPiSetupPhys:longint;cdecl;external;
//extern void pinModeAlt          (int pin, int mode) ;
Procedure pinModeAlt(pin:longint; mode:longint);cdecl;external;
//extern void pinMode             (int pin, int mode) ;
Procedure pinMode(pin:longint; mode:longint);cdecl;external;
//extern void pullUpDnControl     (int pin, int pud) ;
Procedure pullUpDnControl(pin:longint; pud:longint);cdecl;external;
//extern int  digitalRead         (int pin) ;
Function digitalRead(pin:longint):longint;cdecl;external;
//extern void digitalWrite        (int pin, int value) ;
Procedure digitalWrite(pin:longint; value:longint);cdecl;external;
//extern void pwmWrite            (int pin, int value) ;
Procedure pwmWrite(pin:longint; value:longint);cdecl;external;
//extern int  analogRead          (int pin) ;
Function analogRead(pin:longint):longint;cdecl;external;
//extern void analogWrite         (int pin, int value) ;
Procedure analogWrite(pin:longint; value:longint);cdecl;external;


// PiFace specifics
//	(Deprecated)

//extern int  wiringPiSetupPiFace (void) ;
//extern int  wiringPiSetupPiFaceForGpioProg (void) ;	// Don't use this - for gpio program only

// On-Board Raspberry Pi hardware specific stuff

//extern int  piBoardRev          (void) ;
Function piBoardRev:longint;cdecl;external;
//extern void piBoardId           (int *model, int *rev, int *mem, int *maker, int *overVolted) ;
              // TO DO this will be fun ....
//extern int  wpiPinToGpio        (int wpiPin) ;
Function wpiPinToGpio(wpiPin:longint):longint;cdecl;external;
//extern int  physPinToGpio       (int physPin) ;
Function physPinToGpio(physPin:longint):longint;cdecl;external;
//extern void setPadDrive         (int group, int value) ;
Procedure setPadDrive(group:longint; value:longint);cdecl;external;
//extern int  getAlt              (int pin) ;
Function getAlt(pin:longint):longint;cdecl;external;
//extern void pwmToneWrite        (int pin, int freq) ;
Procedure pwmToneWrite(group:longint; freq:longint);cdecl;external;
//extern void digitalWriteByte    (int value) ;
Function digitalWriteByte(value:longint):longint;cdecl;external;
//extern void pwmSetMode          (int mode) ;
Procedure pwmSetMode(mode:longint);cdecl;external;
//extern void pwmSetRange         (unsigned int range) ;
Procedure pwmSetRange(range:dword);cdecl;external;     //unsigned
//extern void pwmSetClock         (int divisor) ;
Procedure pwmSetClock(divisor:longint);cdecl;external;
//extern void gpioClockSet        (int pin, int freq) ;
Procedure gpioClockSet(pin:longint; freq:longint);cdecl;external;


// Interrupts
//	(Also Pi hardware specific)

//extern int  waitForInterrupt    (int pin, int mS) ;
 Function waitForInterrupt(pin:longint;mS:longint):longint;cdecl;external;
//extern int  wiringPiISR         (int pin, int mode, void (*function)(void)) ;

// Threads

//extern int  piThreadCreate      (void *(*fn)(void *)) ;
//extern void piLock              (int key) ;
//extern void piUnlock            (int key) ;

// Schedulling priority

//extern int piHiPri (const int pri) ;

// Extras from arduino land

//extern void         delay             (unsigned int howLong) ;
Procedure delay(howLong:dword);cdecl;external;
//extern void         delayMicroseconds (unsigned int howLong) ;
Procedure delayMicroseconds(howLong:dword);cdecl;external;
//extern unsigned int millis            (void) ;
Function millis:dword;cdecl;external;
//extern unsigned int micros            (void) ;
Function micros:dword;cdecl;external;

// where ?

Procedure wiringPiGpioMode(mode:longint);cdecl;external;





//extern void gpioClockSet        (int pin, int freq) ;



implementation


end.
